package com.community.huiju.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.community.commom.mode.ResponseBean;
import com.community.commom.utils.BeanTools;
import com.community.huiju.dao.*;
import com.community.huiju.model.*;
import com.community.huiju.service.ITpActivitySignUpService;
import com.community.huiju.vo.ActivitySignUpVO;
import com.google.common.collect.Maps;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 物业web端活动报名表 服务实现类
 * </p>
 *
 * @author weiximei
 * @since 2019-01-03
 */
@Service
public class TpActivitySignUpServiceImpl extends ServiceImpl<TpActivitySignUpMapper, TpActivitySignUp> implements ITpActivitySignUpService {

    @Autowired
    private TpActivityMapper tpActivityMapper;

    @Autowired
    private TpActivitySignUpMapper tpActivitySignUpMapper;

    @Autowired
    private TaUserMapper taUserMapper;

    @Autowired
    private TpBuildingOwnerInfoMapper tpBuildingOwnerInfoMapper;

    @Autowired
    private TaSysRoleMapper taSysRoleMapper;



    @Override
    public ResponseBean getSignUpUser(String parameter) {
        ResponseBean responseBean = new ResponseBean();

        JSONObject jsonObject = JSONObject.parseObject(parameter);
        Integer activityId = jsonObject.getInteger("id");
        Integer pageNum = jsonObject.getInteger("pageNum");
        Integer pageSize = jsonObject.getInteger("pageSize");
        String userName = jsonObject.getString("userName");
        String phone = jsonObject.getString("phone");

        TpActivity tpActivity = tpActivityMapper.selectById(activityId);
        if (null == tpActivity) {
            responseBean.addError("活动不存在!");
            return responseBean;
        }

        Page<TpActivitySignUp> page = new Page<>();
        page.setCurrent(null == pageNum ? 0 : pageNum);
        page.setSize(null == pageSize ? 10 : pageSize);
        page.setDesc("sign_up_time");

        IPage<TpActivitySignUp> signUpIPage = tpActivitySignUpMapper.listQuery(page, userName, phone);

        List<TpActivitySignUp> tpActivitySignUpList = signUpIPage.getRecords();
        // 数据包装填充
        List<ActivitySignUpVO> activitySignUpVOS = tpActivitySignUpList.stream().map(e->{
            ActivitySignUpVO activitySignUpVO = new ActivitySignUpVO();
            BeanTools.copyProperties(e, activitySignUpVO);

            TaUser taUser = taUserMapper.selectByPrimaryKey(e.getTaUserId());
            TaSysRole taSysRole = taSysRoleMapper.findRoleByUserId(e.getTaUserId());
            TpBuildingOwnerInfo tpBuildingOwnerInfo = tpBuildingOwnerInfoMapper.selectById(taUser.getBuildingOwnerInfoId());

            activitySignUpVO.setUserName(taUser.getUserName());
            activitySignUpVO.setPhone(taUser.getLoginName());
            activitySignUpVO.setRoleName(taSysRole.getRoleName());
            activitySignUpVO.setAddress(tpBuildingOwnerInfo.getPhase() + tpBuildingOwnerInfo.getBuilding()
                    + tpBuildingOwnerInfo.getUnit() + tpBuildingOwnerInfo.getLevel() + tpBuildingOwnerInfo.getRoomNo());

            return activitySignUpVO;
        }).collect(Collectors.toList());

        Map<String, Object> map = Maps.newHashMap();
        map.put("list", activitySignUpVOS);
        map.put("total", signUpIPage.getTotal());
        map.put("pageNum", signUpIPage.getCurrent());
        map.put("pageSize", signUpIPage.getSize());

        responseBean.addSuccess(map);
        return responseBean;
    }
}
